/*
* Dieses Programm besteht im Grunde aus zwei Teilen. Da sind zum einen die Teile, die zwischen / * und * / stehen.
* Diese Teile werden später vom Programm ignoriert, wenn es auf dem Arduino läuft. Es handelt sich hierbei um Kommentare. 
* In den Kommentaren wird das, was in dem Programm passiert, verständlich gemacht.
* Zum anderen gibt es das eigentliche Programm. Das wird farblich anders dargestellt als die Kommentare. Ziel dieses Programmes 
* ist es nicht, Programmierer auszubilden. Es soll vielmehr dem Nutzer vor Augen führen, wie ein Programm grundsätzlich funktioniert.
 */

/*
* Im folgenden Teil des Programms wird den Pins des Arduinos jeweils ein Name gegeben. Damit kann man später im Programm sofort sehen, 
* um welchen Pin es sich handelt. Grundsätzlich wäre es auch möglich, mit den Pin-Nummern zu arbeiten. Das wird aber schnell 
* unübersichtlich und es können Fehler passieren, die man dann lange suchen muss.
* In den folgenden Programmzeilen passiert im Grunde Folgendes: Es wird eine "Schublade" in einer Kommode gebaut, 
* die später Informationen enthalten soll. Je nachdem, welche Art von Information man hat – einen Zahlenwert, einen Namen oder 
* irgend eine andere digitale Information – benutzt man unterschiedliche Schubladen. "const int" bezeichnet eine universell einsetzbare 
* Schublade, in der man fast alles lagern kann. 
* Nach der Beschreibung, um welche Art von Schublade es sich handeln soll, folgt der Name, der später auf der Schublade stehen soll, 
* damit man gleich weiß, was drin ist. Die Schublade in der ersten Zeile (es ist eine "const int"-Schublade) wird mit dem Namen PINAND1 
* bezeichnet. Der Name ist von den Programmierenden extra so gewählt worden. Es handelt sich nämlich um den ersten Eingang eines 
* logischen AND und es handelt sich um einen Pin. PINAND2 ist demnach der zweite Eingang des logischen AND und PINOR1 ist der erste 
* Eingang eines logischen OR. So wurde das für alle Pins gehalten. 
* Die Ausgänge der logischen Gatter heißen entsprechend PINANDOUT usw.
* Am Ende des Programmabschnitts stehen zwei andere Schubladentypen, nämlich "int". Die sind notwendig, weil die "const int"-Schubladen 
* die Werte, die von den analogen Pins PINAIN und PINADIN ausgegeben werden, nicht speichern können. Da passen Information und 
* Schublade einfach nicht zusammen. Es ist ein bisschen so, als wollte man einen Basketball durch einen Briefkastenschlitz schieben.
 */

 
const int PINAND1 = 2;
const int PINAND2 = 3;
const int PINOR1 = 4;
const int PINOR2 = 5;
const int PINXOR1 = 6;
const int PINXOR2 = 7;
const int PINNOT = 8;
const int PINADOUT = 9;
const int PINOROUT = 12;
const int PINXOROUT = 11;
const int PINNOTOUT = 10;
const int PINANDOUT = 13;
const int PINAIN = A1;
const int PINADIN = A6;
int AnalogIn = 0;
int ADschalter = 0;



/*
 * Nachdem die Schubladen benannt sind und die Werte den Schubladen zugewiesen wurden, muss dem Programm gesagt werden, wie es mit den Werten 
 * in der Schublade umgehen soll. Die Pins können auf zwei Arten genutzt werden, als Input oder als Output.Inputs kann man sich wie Ohren 
 * vorstellen. Mit Ohren kann man zwar hören, aber nicht sprechen. Dafür braucht man einen Mund. Ein Pin kann entweder ein Mund oder 
 * ein Ohr sein - beides geht nicht. Wenn wir über den Pin Informationen empfangen wollen, dann müssen wir ihn als INPUT bezeichnen, 
 * wenn wir über den Pin etwas senden wollen, dann müssen wir ihn als OUTPUT definieren.
 * Die folgenden Befehle setzen sich aus dem Befehl "pinMode" und in Klammern dem Namen der Schublade, einem Komma und dem Befehl INPUT 
 * oder OUTPUT zusammen. Diese Programmzeile sagt also aus, dass der Pin mit dem Namen PINAND1 ein INPUT ist, also wie ein Ohr hört. 
 * Der Pin mit dem Namen PINANDOUT dagegen ist wie ein Mund ein OUTPUT; er wird Signale aus dem Arduino nach außen geben.
 * Der Befehl "void setup()" sowie die geschweiften Klammern oben und unten sagen dem Programm, dass in diesem Programmteil das passiert, 
 * was oben beschrieben wurde, nämlich die Zuweisung der Pins zu INPUT oder OUTPUT.
 */




void setup() { 
  
pinMode(PINAND1, INPUT);
pinMode(PINAND2, INPUT);
pinMode(PINOR1, INPUT);
pinMode(PINOR2, INPUT);
pinMode(PINXOR1, INPUT);
pinMode(PINXOR2, INPUT);
pinMode(PINNOT, INPUT);
pinMode(PINANDOUT, OUTPUT);
pinMode(PINOROUT, OUTPUT);
pinMode(PINXOROUT, OUTPUT);
pinMode(PINNOTOUT, OUTPUT);
pinMode (PINADOUT, OUTPUT);
pinMode (PINAIN, INPUT);
pinMode (PINADIN, INPUT);
}





/*
 * Nachdem dem Programm erklärt wurde, welche Pins Informationen aufnehmen und speichern und welche Pins Informationen nach außen geben, 
 * muss man dem Programm jetzt noch sagen, wann das passieren soll.Denken wir uns eine Apotheke, in der es auch viele beschriftete Schubladen 
 * gibt. Die Fachkraft in der Apotheke muss wissen, wann sie etwas aus einer Schublade nehmen soll und wann sie etwas in welche Schublade einsortieren soll. 
 * "Wenn ein Kunde mit einem Rezept von einem Arzt kommt, dann nimm das Produkt aus der richtigen Schublade und gib es dem Kunden", könnte so 
 * eine Anweisung sein, bei der ein Wert ausgegeben wird. "Wenn du dem Kunden das Produkt gegeben hast, dann nimm das Geld und lege es in die Kasse", 
 * wäre eine Anweisung zum Speichern einer Information. Im Programm ist das ganz ähnlich, allerdings wird in englischer Sprache geschrieben und es 
 * werden spezielle Zeichen verwendet, die aber im Grunde nichts weiter machen, als dem Arduino in seiner Sprache zu erklären, was eben mit der 
 * Apotheke erläutert wurde. "void loop()" sagt dem Programm, dass alles, was innerhalb der geschweiften Klammern folgt, das eigentliche Programm 
 * ist und das dies immer wieder durchlaufen werden soll. 
 */




void loop() 
{
 
/*
 * Der folgende Block beginnt mit dem Begriff "if" und endet mit einer geschweiften Klammer ganz unten. Was wird dem Programm hier gesagt?
 * "If" ist das englische Wort für "wenn". "Wenn etwas passiert" wird gefolgt von dem Befehl "digitalRead(PINAND1)". Von PINAND1 wissen wir, dass er ein "Ohr" 
 * ist und dafür genutzt wird, Informationen aufzunehmen. Er ist ein INPUT. "digitalRead" heißt in Menschensprache soviel wie "hör genau hin, liebes Ohr, was hörst du?".
 * Bislang wissen wir noch nicht, was das Ohr hören muss, damit etwas passiert. Es folgen also in der Zeile zwei Gleichheitszeichen "==" (das ist kein Tippfehler) 
 * und der Begriff HIGH. Zwei Gleichheitszeichen werden in der Programmlogik übersetzt als "hat den Wert" und HIGH und LOW geben an, ob ein Pin gerade aktiv ist oder 
 * nicht. So ergibt sich also die Programmzeile "wenn PINAND1 ein aktives Eingangssignal wahrnimmt"... dann was? Es geht weiter mit zwei anderen gleichen Zeichen, 
 * dem UND "&". Zwei "&" werden übersetzt als logisches UND. Damit der gesamte Ausdruck wahr ist, müssen beide Bedingungen des && wahr sein. Hier bedeutet es, 
 * dass PINAND1 HIGH sein soll und dass PINAND2 auch HIGH sein soll. Jetzt lässt sich lesen: „Wenn PINAND1 HIGH ist und außerdem auch noch PINAND2 auch HIGH ist, dann ...“
 * Es folgen geschweifte Klammern und ein Befehl dazwischen. Der lautet diesmal "digitalWrite". Es soll also als Ausgabe etwas geschrieben werden. Da passt es, 
 * dass es um den Pin PINANDOUT geht, der ein OUTPUT ist. Soweit haben wir also entschlüsselt: Wenn PINAND1 HIGH ist und außerdem auch noch PINAND2 HIGH ist, 
 * dann soll PINANDOUT auch HIGH sein. In Abhängigkeit der Eingänge wird der Ausgang geschaltet. Wenn, dann ... sonst passiert was? Hier wird „sonst“ durch das englische 
 * "else" ausgedrückt. Den Befehl "digitalWrite" kennen wir bereits. Diesmal soll PINANDOUT also nicht HIGH gesetzt werden, sondern „seinen Mund halten“ und LOW 
 * als Ausgangssignal ausgeben - also kein Signal. Diese Logik wiederholt sich mehrfach. Versuche die anderen "wenn-dann-sonst“ zu entschlüsseln.
 */



if (digitalRead(PINAND1)==HIGH 
&& digitalRead(PINAND2)==HIGH) 
  {
  digitalWrite (PINANDOUT, HIGH);
  }
  else
  {
    digitalWrite (PINANDOUT, LOW);
  }



if (digitalRead(PINOR1)==HIGH || digitalRead(PINOR2)==HIGH) 
  {
  digitalWrite (PINOROUT, HIGH);
  }
  else
  {
    digitalWrite (PINOROUT, LOW);
  }



if ((digitalRead (PINXOR1) ==HIGH &&  digitalRead (PINXOR2) == LOW) || (digitalRead (PINXOR1) ==LOW &&  digitalRead (PINXOR2) == HIGH))
  {
  digitalWrite (PINXOROUT, HIGH);
  }
  else
  {
    digitalWrite (PINXOROUT, LOW);
  }


  
if (digitalRead(PINNOT)==HIGH) 
  {
  digitalWrite (PINNOTOUT, LOW);
  }
  else
  {
    digitalWrite (PINNOTOUT, HIGH);
  }





/*
 * Die folgenden Befehle beziehen sich nicht auf die digitalen Pins, sondern auf die analogen. Dies ist eine Sternchenaufgabe, die ein bisschen schwieriger ist.
 * AnalogIn und ADschalter wurden zu Beginn des Programms als „int“ definiert. Mit dem Befehl "AnalogIn = analogRead(PINAIN)" wird dem Arduino gesagt, dass er 
 * den Analogwert am PINANIN lesen und danach in der Schublade AnalogIn speichern soll. Analogwerte im Arduino können zwischen 0 und 1000 liegen. 
 * In der folgenden Wenn-dann-sonst-Bedingung wird dem Arduino gesagt, dass er, wenn der Wert in der entsprechenden Schublade größer als 500 ist, etwas machen soll. 
 * Bei der Variablen "AnalogIn" wird beim Überschreiten des Analogwerts 500 der Pin PINADOUT (natürlich ein OUTPUT) HIGH gesetzt. Der ganze Programmblock ist ein 
 * bisschen komplexer. Versuche zu entschlüsseln, welche Funktion der Programmblock genau hat.
 */





AnalogIn = analogRead(PINAIN);
ADschalter = analogRead (PINADIN);

if (ADschalter > 500)
  {
    if (AnalogIn > 500)
    {
    digitalWrite (PINADOUT, HIGH);
    }
    else
    {
      digitalWrite (PINADOUT, LOW);
    }
  }
  else
  {
  analogWrite (PINADOUT, AnalogIn);
  Serial.println(AnalogIn);
  }
}


